@@ -10,7 +10,7 @@ import time
 
 import h2o
 from h2o.exceptions import H2OConnectionError, H2OServerError
-from h2o.display import H2ODisplay
+from h2o.display import H2OTableDisplay
 from h2o.schemas import H2OSchema
 from h2o.utils.typechecks import assert_is_type
 from h2o.utils.shared_utils import get_human_readable_bytes, get_human_readable_time
@@ -131,13 +131,13 @@ class H2OCluster(H2OSchema):
         keys = _cluster_status_info_keys
         values = self._get_cluster_status_info_values()
         table = [[k+":", values[i]] for i, k in enumerate(keys)]
-        H2ODisplay(table)
+        H2OTableDisplay(table, prefer_pandas=False).show()
 
         if detailed:
             keys = _cluster_status_detailed_info_keys
-            header = ["Nodes info:"] + ["Node %d" % (i + 1) for i in range(len(self.nodes))]
+            columns = ["Nodes info:"] + ["Node %d" % (i + 1) for i in range(len(self.nodes))]
             table = [[k]+[node[k] for node in self.nodes] for k in keys]
-            H2ODisplay(table=table, header=header)
+            H2OTableDisplay(table=table, columns_labels=columns, prefer_pandas=False).show()
 
     def get_status(self):
         """
@@ -279,7 +279,6 @@ class H2OCluster(H2OSchema):
             status += ", healthy"
         else:
             status += ", %d nodes are not healthy" % unhealthy_nodes
-        api_extensions = self.list_api_extensions()
         values = [get_human_readable_time(self.cloud_uptime_millis),
                   self.cloud_internal_timezone,
                   self.datafile_parser_timezone,
@@ -294,7 +293,6 @@ class H2OCluster(H2OSchema):
                   h2o.connection().base_url,
                   json.dumps(h2o.connection().proxy),
                   self.internal_security_enabled,
-                  ', '.join(api_extensions),
                   "%d.%d.%d %s" % tuple(sys.version_info[:4])]
         return values
 
@@ -302,7 +300,7 @@ class H2OCluster(H2OSchema):
 _cluster_status_info_keys = ["H2O_cluster_uptime", "H2O_cluster_timezone", "H2O_data_parsing_timezone",
             "H2O_cluster_version", "H2O_cluster_version_age", "H2O_cluster_name", "H2O_cluster_total_nodes",
             "H2O_cluster_free_memory", "H2O_cluster_total_cores", "H2O_cluster_allowed_cores", "H2O_cluster_status",
-            "H2O_connection_url", "H2O_connection_proxy", "H2O_internal_security", "H2O_API_Extensions", "Python_version"]
+            "H2O_connection_url", "H2O_connection_proxy", "H2O_internal_security", "Python_version"]
     
 _cluster_status_detailed_info_keys = ["h2o", "healthy", "last_ping", "num_cpus", "sys_load", "mem_value_size",
                                       "free_mem", "pojo_mem", "swap_mem", "free_disk", "max_disk", "pid", "num_keys",
